parser

package module
v0.0.0-...-bb92a23 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 15, 2017 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

const FLOAT_LIT = 57409
const INT_LIT = 57408
const KW_ADD = 57406
const KW_ALTER = 57383
const KW_AND = 57362
const KW_AS = 57405
const KW_AUTO_INCREMENT = 57397
const KW_AVG = 57391
const KW_BETWEEN = 57385
const KW_BOOLEAN = 57367
const KW_BY = 57372
const KW_CHAR = 57366
const KW_COLUMN = 57407
const KW_COUNT = 57390
const KW_CREATE = 57373
const KW_DATETIME = 57368
const KW_DEFAULT = 57402
const KW_DELETE = 57375
const KW_DROP = 57401
const KW_FALSE = 57404
const KW_FLOAT = 57365
const KW_FOREIGN = 57370
const KW_FROM = 57380
const KW_GROUP = 57400
const KW_HAVING = 57388
const KW_IN = 57395
const KW_INNER = 57387
const KW_INSERT = 57376
const KW_INTEGER = 57364
const KW_INTO = 57377
const KW_IS = 57396
const KW_JOIN = 57398
const KW_KEY = 57371
const KW_LIKE = 57386
const KW_MAX = 57393
const KW_MIN = 57392
const KW_NOT = 57363
const KW_NULL = 57394
const KW_ON = 57399
const KW_OR = 57361
const KW_PRIMARY = 57369
const KW_SELECT = 57378
const KW_SET = 57382
const KW_SUM = 57389
const KW_TABLE = 57374
const KW_TRUE = 57403
const KW_UPDATE = 57381
const KW_VALUES = 57384
const KW_WHERE = 57379
const STR_LIT = 57411
const TK_COMMA = 57358
const TK_DIV = 57349
const TK_DOT = 57359
const TK_EQ = 57354
const TK_GT = 57351
const TK_GTE = 57352
const TK_ID = 57410
const TK_LEFT_PAR = 57356
const TK_LT = 57350
const TK_LTE = 57353
const TK_MINUS = 57347
const TK_NE = 57355
const TK_PLUS = 57346
const TK_RIGHT_PAR = 57357
const TK_SEMICOLON = 57360
const TK_STAR = 57348

Variables

This section is empty.

Functions

func Parse

func Parse(in io.Reader) (commands []interface{}, err error)

Types

type Error

type Error struct {
	// contains filtered or unexported fields
}

Error provides information about errors that occurred during parsing or execution.

func (Error) Column

func (e Error) Column() int

Column returns the column number in which the error occurred.

func (Error) Error

func (e Error) Error() string

func (Error) Line

func (e Error) Line() int

Line returns the line number in which the error occurred.

func (Error) Message

func (e Error) Message() string

Message returns a description of the error that occurred.

type GroupBySpec

type GroupBySpec struct {
	// contains filtered or unexported fields
}

type Lexer

type Lexer struct {
	// contains filtered or unexported fields
}

func NewLexer

func NewLexer(in io.Reader) *Lexer

func NewLexerWithInit

func NewLexerWithInit(in io.Reader, initFun func(*Lexer)) *Lexer

NewLexerWithInit creates a new Lexer object, runs the given callback on it, then returns it.

func (*Lexer) Column

func (yylex *Lexer) Column() int

Column returns the current column number. The first column is 0.

func (*Lexer) Error

func (l *Lexer) Error(s string)

func (*Lexer) Lex

func (yylex *Lexer) Lex(lval *yySymType) int

Lex runs the lexer. Always returns 0. When the -s option is given, this function is not generated; instead, the NN_FUN macro runs the lexer.

func (*Lexer) Line

func (yylex *Lexer) Line() int

Line returns the current line number. The first line is 0.

func (*Lexer) Stop

func (yyLex *Lexer) Stop()

func (*Lexer) Text

func (yylex *Lexer) Text() string

Text returns the matched text.

Jump to